# YoutubeTags
Python Library to Extract youtube video Tags without Youtube API

[![CodeQL](https://github.com/bughunter0/YoutubeTags/actions/workflows/codeql-analysis.yml/badge.svg)](https://github.com/bughunter0/YoutubeTags/actions/workflows/codeql-analysis.yml)
[![Downloads](https://pepy.tech/badge/Youtubetags)](https://pepy.tech/project/YoutubeTags)
[![Supported Versions](https://img.shields.io/pypi/pyversions/Youtubetags.svg)](https://pypi.org/project/YoutubeTags)
![GitHub](https://img.shields.io/github/license/bughunter0/YoutubeTags)
![PyPI](https://img.shields.io/pypi/v/youtubetags)
![PyPI - Downloads](https://img.shields.io/pypi/dm/youtubetags)
![PyPI - Format](https://img.shields.io/pypi/format/youtubetags)


## Installation

```python
pip install YoutubeTags

```
## Example
```python
import YoutubeTags
from YoutubeTags import videotags
findtags = videotags("https://www.youtube.com/watch?v=RTbrXiIzUt4")
print(findtags)
```
<details>
  <summary><b>Output</b></summary>
<br/>

```
Right To Repair, right to repair, MKBHD, right to repair movement, Apple, Apple vs, 
repairing iPhone, iPhone 12, Tesla right to repair, Apple right to repair

```

</details>


<b>© 2021 Nuhman Pk , LICENSED under MIT License</b>

## Github

Follow me on [Github](https://www.github.com/bughunter0) and if you find this [library](https://github.com/bughunter0/YoutubeTags) useful don't forget to add Your star

## Sponsor this project
[ko-fi](https://ko-fi.com/nuhmanpk)<br>
[paypal](https://www.paypal.me/nuhmanpk)
